local addonName = "WhatsTraining"
local wt = _G[addonName]

-- Spell Cache
wt.petAbilities = {}
wt.spellInfoCache = {}

-- done has param cacheHit
function wt:CacheSpell(spell, level, done)
    if (self.spellInfoCache[spell.id] ~= nil) then
        done(true)
        return
    end
    local name, rank, icon, cost, isFunnel, powerType, castTime, minRage, maxRange = GetSpellInfo(spell.id);
    self.spellInfoCache[spell.id] = {
        id = spell.id,
        name = name,
        subText = rank, --subText,
        formattedSubText = (rank and rank ~= "") and format(PARENS_TEMPLATE, rank) or "",
        icon = icon,
        cost = spell.cost,
        formattedCost = GetCoinTextureString(spell.cost),
        level = level,
        formattedLevel = format(wt.L.LEVEL_FORMAT, level)
    }
    if (self:IsPetAbility(spell.id)) then
        if (formattedSubText ~= "") then
            self.petAbilities[si:GetSpellName() .. " " .. formattedSubText] = self.spellInfoCache[spell.id]
        else
            self.petAbilities[si:GetSpellName()] = self.spellInfoCache[spell.id]
        end
    end
    done(false)
end

function wt:SpellInfo(spellId) return self.spellInfoCache[spellId] end

function wt:PetAbility(forName) return self.petAbilities[forName] end

-- Item Cache
wt.itemInfoCache = {}
-- for warlock pet tomes, the name includes the rank
-- however, this will cause overlap with the level text and there's no good way to fix it with setting points
-- instead, strip the rank text out of the name and put it as the subText
local parensPattern = " (%(.+%))"
function wt:CacheItem(item, level, done)
    if (self.itemInfoCache[item.id] ~= nil) then
        done(true)
        return
    end
    local itemName, itemLink, itemQuality, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture, sellPrice = GetItemInfo(item)
    local rankText = string.match(itemName, parensPattern)
    self.itemInfoCache[item.id] = {
        id = item.id,
        name = string.gsub(itemName, parensPattern, ""),
        formattedSubText = rankText,
        icon = itemTexture,
        cost = item.cost,
        formattedCost = GetCoinTextureString(item.cost),
        level = level,
        formattedLevel = format(wt.L.LEVEL_FORMAT, level),
        isItem = true
    }
    done(false)
end

function wt:ItemInfo(itemId) return self.itemInfoCache[itemId] end
